Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: runtime/vm/assembler_arm64.cc

Issue 339183010: Specialize breakpoint stubs by set of live registers of the stubs they are intercepting. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/assembler_arm64.h ('k') | runtime/vm/assembler_x64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/assembler_arm64.cc
diff --git a/runtime/vm/assembler_arm64.cc b/runtime/vm/assembler_arm64.cc
index d52dd1e87fb7d2cd3536216697711433ced267e6..c305357282a0f90f1100e8b0099d8b0ec332e10e 100644
--- a/runtime/vm/assembler_arm64.cc
+++ b/runtime/vm/assembler_arm64.cc
@@ -67,11 +67,30 @@ Assembler::Assembler(bool use_far_branches)
patchable_pool_entries_.Add(kNotPatchable);
}
- // Create fixed object pool entry for debugger stub.
- if (StubCode::BreakpointRuntime_entry() != NULL) {
+ // Create fixed object pool entries for debugger stubs.
+ if (StubCode::ICCallBreakpoint_entry() != NULL) {
intptr_t index =
- FindExternalLabel(&StubCode::BreakpointRuntimeLabel(), kNotPatchable);
- ASSERT(index == kBreakpointRuntimeCPIndex);
+ FindExternalLabel(&StubCode::ICCallBreakpointLabel(),
+ kNotPatchable);
+ ASSERT(index == kICCallBreakpointCPIndex);
+ } else {
+ object_pool_.Add(vacant, Heap::kOld);
+ patchable_pool_entries_.Add(kNotPatchable);
+ }
+ if (StubCode::ClosureCallBreakpoint_entry() != NULL) {
+ intptr_t index =
+ FindExternalLabel(&StubCode::ClosureCallBreakpointLabel(),
+ kNotPatchable);
+ ASSERT(index == kClosureCallBreakpointCPIndex);
+ } else {
+ object_pool_.Add(vacant, Heap::kOld);
+ patchable_pool_entries_.Add(kNotPatchable);
+ }
+ if (StubCode::RuntimeCallBreakpoint_entry() != NULL) {
+ intptr_t index =
+ FindExternalLabel(&StubCode::RuntimeCallBreakpointLabel(),
+ kNotPatchable);
+ ASSERT(index == kRuntimeCallBreakpointCPIndex);
} else {
object_pool_.Add(vacant, Heap::kOld);
patchable_pool_entries_.Add(kNotPatchable);
« no previous file with comments | « runtime/vm/assembler_arm64.h ('k') | runtime/vm/assembler_x64.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698